<?php
/**
 * Blocks Initializer
 *
 * Enqueue CSS/JS of all the blocks.
 *
 * @since   1.0.0
 * @package CGB
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Enqueue Gutenberg block assets for both frontend + backend.
 *
 * Assets enqueued:
 * 1. blocks.style.build.css - Frontend + Backend.
 * 2. blocks.build.js - Backend.
 * 3. blocks.editor.build.css - Backend.
 *
 * @uses {wp-blocks} for block type registration & related functions.
 * @uses {wp-element} for WP Element abstraction — structure of blocks.
 * @uses {wp-i18n} to internationalize the block's text.
 * @uses {wp-editor} for WP editor styles.
 * @since 1.0.0
 */
function keni_block_cgb_block_assets() { // phpcs:ignore
	// Register block styles for both frontend + backend.
	wp_register_style(
		'keni_block-cgb-style-css', // Handle.
		get_theme_file_uri( 'keni/module/keni-block-editor/dist/blocks.style.build.css' ), // Block style CSS.
		array( 'wp-editor' ), // Dependency to include the CSS after it.
		null // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.style.build.css' ) // Version: File modification time.
	);

	// Register block editor script for backend.
	wp_register_script(
		'keni_block-cgb-block-js', // Handle.
		get_theme_file_uri( 'keni/module/keni-block-editor/dist/blocks.build.js' ), // Block.build.js: We register the block here. Built with Webpack.
		array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor' ), // Dependencies, defined above.
		null, // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.build.js' ), // Version: filemtime — Gets file modification time.
		true // Enqueue the script in the footer.
	);

	// Register block editor styles for backend.
	wp_register_style(
		'keni_block-cgb-block-editor-css', // Handle.
		get_theme_file_uri( 'keni/module/keni-block-editor/dist/blocks.editor.build.css' ), // Block editor CSS.
		array( 'wp-edit-blocks' ), // Dependency to include the CSS after it.
		null // filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.editor.build.css' ) // Version: File modification time.
	);

	/**
	 * Register Gutenberg block on server-side.
	 *
	 * Register the block on server-side to ensure that the block
	 * scripts and styles for both frontend and backend are
	 * enqueued when the editor loads.
	 *
	 * @link https://wordpress.org/gutenberg/handbook/blocks/writing-your-first-block-type#enqueuing-block-scripts
	 * @since 1.16.0
	 */
	if ( function_exists( 'register_block_type' ) ) {
		register_block_type(
			'cgb/block-my-block', array(
				// Enqueue blocks.style.build.css on both frontend & backend.
				'style'         => 'keni_block-cgb-style-css',
				// Enqueue blocks.build.js in the editor only.
				'editor_script' => 'keni_block-cgb-block-js',
				// Enqueue blocks.editor.build.css in the editor only.
				'editor_style'  => 'keni_block-cgb-block-editor-css',
			)
		);
	}
}

// オリジナルのカテゴリーを追加する
function keni_plugin_block_categories( $categories, $post ) {
	return array_merge(
			$categories,
			array(
					array(
							'slug' => 'keni-editor',   //ブロックカテゴリーのスラッグ
							'title' => '賢威カスタムブロック',  //ブロックカテゴリーの表示名
							'icon'  => 'layout',    //アイコンの指定（Dashicons名）
					),
			)
	);
}

if ( function_exists( 'register_block_type' ) ) {
	// Hook: Block assets.
	add_action( 'init', 'keni_block_cgb_block_assets' );

	add_filter( 'block_categories', 'keni_plugin_block_categories', 10, 2 );
}
