import './style.scss';
import './editor.scss';
import { Fragment } from '@wordpress/element';
// import apiFetch from '@wordpress/api-fetch';

const { __ } = wp.i18n;

const {
	RichText,
	InspectorControls,
} = wp.editor;

const {
	PanelBody,
	RadioControl,
} = wp.components;

const {
	registerBlockType,
} = wp.blocks;

registerBlockType( 'keni-block/keni-block', {
	title: __( 'ボックスコンテンツ', 'keni' ),
	icon: 'feedback',
	category: 'keni-editor',
	attributes: {
		title: {
			type: 'array',
			source: 'children',
			selector: 'span',
		},
		content: {
			type: 'array',
			source: 'children',
			selector: 'p',
		},
		boxcolor: {
			type: 'string',
			default: 'box_style box_style_blue',
		},
	},
	supports: {
		//save関数で返される要素に対する設定
		align: false, //(default:false) ブロックのalign設定。配列で個別指定も可能 (left, center, right, wide, full)
		alignWide: false, //(default:true)全幅・幅広表示の設定。falseで無効にする
		anchor: false, //(default:false)アンカーリンクの設定。
		customClassName: true, //(default:true)クラス名の設定。有効にするとオリジナルのクラス名を入力する欄が表示される。
		className: false, //(default:true)ブロック要素を作成した際に付く.wp-block-[ブロック名]で自動生成されるクラス名の設定。
		html: true, //(default:true)HTMLでの編集設定。通常Gutenbergはビジュアル編集ですが、trueでHTML編集が選択可能になります。
		inserter: true, //(default:true)trueで「ブロックの追加」ボタンからこのブロック要素を選択可能にします。falseでブロック要素の選択画面からこのブロック要素を隠します。
		multiple: true, //(default:true)trueでこのブロック要素を一つのページで複数作成可能になります。
		reusable: true, //(default:true)trueで再利用可能なブロックに追加する設定が選択可能になります。
	},
	edit: ( props ) => {
		const {
			attributes: {
				title,
				content,
				boxcolor,
			},
			setAttributes,
		} = props;

		const onChangeTitle = ( value ) => {
			setAttributes( { title: value } );
		};

		const onChangeContent = ( value ) => {
			setAttributes( { content: value } );
		};

		const onChangeBoxColor = ( value ) => {
			setAttributes( { boxcolor: value } );
		};

		return (
			<Fragment>
				<InspectorControls>
					<PanelBody title="ボックスカラー">
						<RadioControl
							label="ボックスカラー"
							help="ボックスカラーを選んでください"
							selected={ boxcolor }
							options={ [
								{ label: '青色', value: 'box_style box_style_blue' },
								{ label: '緑色', value: 'box_style box_style_green' },
								{ label: 'オレンジ', value: 'box_style box_style_orange' },
								{ label: '赤色', value: 'box_style box_style_red' },
								{ label: 'ピンク', value: 'box_style box_style_pink' },
								{ label: '黄色', value: 'box_style box_style_yellow' },
								{ label: 'グレー', value: 'box_style box_style_gray' },
							] }
							onChange={ onChangeBoxColor }
						/>
					</PanelBody>
				</InspectorControls>
				<div className={ boxcolor }>
					<div className="box_inner">
						<div className="box_style_title">
							<RichText
								tagName="span"
								className="box_style_title_inner"
								placeholder={ __( 'ここにタイトルが入ります', 'custom-block' ) }
								value={ title }
								onChange={ onChangeTitle }
								keepPlaceholderOnFocus={ false }
							/>
						</div>
						<RichText
							tagName="p"
							onChange={ onChangeContent }
							value={ content }
							placeholder={ __( 'ここにはコンテンツを記載', 'custom-block' ) }
							keepPlaceholderOnFocus={ false }
						/>
					</div>
				</div>
			</Fragment>
		);
	},
	save: ( props ) => {
		const {
			attributes: {
				title,
				content,
				boxcolor,
			},
		} = props;
		return (
			<div className={ boxcolor }>
				<div className="box_inner">
					<div className="box_style_title">
						<RichText.Content
							tagName="span"
							className="box_style_title_inner"
							value={ title }
						/>
					</div>
					<RichText.Content
						tagName="p"
						value={ content }
					/>
				</div>
			</div>
		);
	},
} );

const precautionaryNote = 'keni-block/precautionary-note';
registerBlockType( precautionaryNote, {
	title: __( '※注意書き', 'keni' ),
	icon: 'warning',
	category: 'keni-editor',
	attributes: {
		note: {
			type: 'array',
			source: 'children',
			selector: 'span',
			className: 'note',
			default: '※注意書き',
		},
	},
	supports: {
		align: true,
		alignWide: true,
		anchor: true,
		customClassName: true,
		className: false,
		html: true,
		inserter: true,
		multiple: true,
		reusable: true,
	},
	edit: ( props ) => {
		const {
			attributes: {
				note,
			},
			setAttributes,
		} = props;

		const onChangeNote = ( value ) => {
			setAttributes( { note: value } );
		};

		return (
			<Fragment>
				<RichText
					tagName="span"
					className="note"
					value={ note }
					onChange={ onChangeNote }
					keepPlaceholderOnFocus={ true }
				/>
			</Fragment>
		);
	},
	save: ( props ) => {
		const {
			attributes: {
				note,
			},
		} = props;
		return (
			<RichText.Content
				tagName="span"
				className="note"
				value={ note }
			/>
		);
	},
} );

// const keniPostCC = 'keni-block/post-cc';
// registerBlockType( keniPostCC, {
// 	title: __( '賢威共通コンテンツ', 'keni' ),
// 	icon: 'media-code',
// 	category: 'keni-editor',
// 	attributes: {
// 		cc_sc: {
// 			type: 'string',
// 			default: '',
// 		},
// 	},
// 	supports: {
// 		//save関数で返される要素に対する設定
// 		align: false, //(default:false) ブロックのalign設定。配列で個別指定も可能 (left, center, right, wide, full)
// 		alignWide: false, //(default:true)全幅・幅広表示の設定。falseで無効にする
// 		anchor: false, //(default:false)アンカーリンクの設定。
// 		customClassName: true, //(default:true)クラス名の設定。有効にするとオリジナルのクラス名を入力する欄が表示される。
// 		className: false, //(default:true)ブロック要素を作成した際に付く.wp-block-[ブロック名]で自動生成されるクラス名の設定。
// 		html: true, //(default:true)HTMLでの編集設定。通常Gutenbergはビジュアル編集ですが、trueでHTML編集が選択可能になります。
// 		inserter: true, //(default:true)trueで「ブロックの追加」ボタンからこのブロック要素を選択可能にします。falseでブロック要素の選択画面からこのブロック要素を隠します。
// 		multiple: true, //(default:true)trueでこのブロック要素を一つのページで複数作成可能になります。
// 		reusable: true, //(default:true)trueで再利用可能なブロックに追加する設定が選択可能になります。
// 	},
// 	edit: ( props ) => {
// 		const {
// 			attributes: {
// 				cc_sc,
// 			},
// 			setAttributes,
// 		} = props;

// 		const onChangeKeniCC = ( value ) => {
// 			setAttributes( { cc_sc: value } );
// 		};

// 		apiFetch( { path: '/wp/v2/keni_cc' } ).then( posts => {
// 			console.log( posts );
// 		} );

// 		return (
// 			<Fragment>
// 				<InspectorControls>
// 					<PanelBody title="賢威共通コンテンツ">
// 						<RadioControl
// 							label="賢威共通コンテンツ"
// 							help="賢威共通コンテンツを選んでください"
// 							selected={ cc_sc }
// 							options={ [
// 								{ label: '共通コンテンツ1', value: "[cc id='77']" },
// 								{ label: '共通コンテンツ2', value: '2' },
// 								{ label: '共通コンテンツ3', value: '3' },
// 								{ label: '共通コンテンツ4', value: '4' },
// 								{ label: '共通コンテンツ5', value: '5' },
// 								{ label: '共通コンテンツ6', value: '6' },
// 								{ label: '共通コンテンツ7', value: '7' },
// 							] }
// 							onChange={ onChangeKeniCC }
// 						/>
// 					</PanelBody>
// 				</InspectorControls>
// 			</Fragment>
// 		);
// 	},
// 	save: ( props ) => {
// 		const {
// 			attributes: {
// 				cc_sc,
// 			},
// 		} = props;
// 		return (
// 				<div className="keni_cc">
// 					<RichText.Content
// 						tagName="p"
// 						value={ cc_sc }
// 					/>
// 				</div>
// 		);
// 	},
// } );
