import '../style.scss';
import '../editor.scss';
import { Fragment } from '@wordpress/element';

const { __ } = wp.i18n;
const {
	registerFormatType,
	toggleFormat,
} = wp.richText;
const {
	RichTextShortcut,
	BlockControls,
} = wp.editor;

const {
	Toolbar,
	ToolbarButton,
} = wp.components;

const markerYellow = 'keni-block/marker-yellow';
registerFormatType( markerYellow, {
	title: __( 'Marker', 'keni' ),
	tagName: 'span',
	className: 'line-yellow',
	edit: ( props ) => {
		const {
			value,
			// isActive,
			onChange,
		} = props;

		const onToggle = () => {
			return onChange(
				toggleFormat( value, { type: markerYellow } )
			);
		};
		const shortcutType = 'ctrlShift';
		return (
			<Fragment>
				<RichTextShortcut
					type={ shortcutType }
					character={ 'y' }
					onUse={ onToggle }
				/>
				{ /* <RichTextToolbarButton
					icon="admin-customizer"
					title={ __( 'Marker', 'keni' ) }
					onClick={ onToggle }
					isActive={ isActive }
				/> */ }
				<BlockControls>
					<Toolbar>
						<ToolbarButton
							className="components-toolbar__control keni-marker keni-marker-yellow"
							label="マーカーイエロー"
							title="マーカーイエロー"
							icon="editor-textcolor"
							onClick={ onToggle }
						/>
					</Toolbar>
				</BlockControls>
			</Fragment>
		);
	},
} );

const markerOrange = 'keni-block/marker-orange';
registerFormatType( markerOrange, {
	title: __( 'Marker', 'keni' ),
	tagName: 'span',
	className: 'line-orange',
	edit: ( props ) => {
		const {
			value,
			// isActive,
			onChange,
		} = props;

		const onToggle = () => onChange(
			toggleFormat( value, { type: markerOrange } )
		);
		const shortcutType = 'ctrlShift';
		return (
			<Fragment>
				<RichTextShortcut
					type={ shortcutType }
					character={ 'o' }
					onUse={ onToggle }
				/>
				{ /* <RichTextToolbarButton
					icon="admin-customizer"
					title={ __( 'Marker', 'keni' ) }
					onClick={ onToggle }
					isActive={ isActive }
				/> */ }
				<BlockControls>
					<Toolbar>
						<ToolbarButton
							className="components-toolbar__control keni-marker keni-marker-orange"
							label="マーカーオレンジ"
							title="マーカーオレンジ"
							icon="editor-textcolor"
							onClick={ onToggle }
						/>
					</Toolbar>
				</BlockControls>
			</Fragment>
		);
	},
} );

const markerPink = 'keni-block/marker-pink';
registerFormatType( markerPink, {
	title: __( 'Marker', 'keni' ),
	tagName: 'span',
	className: 'line-pink',
	edit: ( props ) => {
		const {
			value,
			// isActive,
			onChange,
		} = props;

		const onToggle = () => onChange(
			toggleFormat( value, { type: markerPink } )
		);
		const shortcutType = 'ctrlShift';
		return (
			<Fragment>
				<RichTextShortcut
					type={ shortcutType }
					character={ 'p' }
					onUse={ onToggle }
				/>
				{ /* <RichTextToolbarButton
					icon="admin-customizer"
					title={ __( 'Marker', 'keni' ) }
					onClick={ onToggle }
					isActive={ isActive }
				/> */ }
				<BlockControls>
					<Toolbar>
						<ToolbarButton
							className="components-toolbar__control keni-marker keni-marker-pink"
							label="マーカーピンク"
							title="マーカーピンク"
							icon="editor-textcolor"
							onClick={ onToggle }
						/>
					</Toolbar>
				</BlockControls>
			</Fragment>
		);
	},
} );

const markerBlue = 'keni-block/marker-blue';
registerFormatType( markerBlue, {
	title: __( 'Marker', 'keni' ),
	tagName: 'span',
	className: 'line-blue',
	edit( props ) {
		const {
			value,
			// isActive,
			onChange,
		} = props;
		const onToggle = () => onChange(
			toggleFormat( value, { type: markerBlue } )
		);
		const shortcutType = 'ctrlShift';
		return (
			<Fragment>
				<RichTextShortcut
					type={ shortcutType }
					character={ 'b' }
					onUse={ onToggle }
				/>
				{ /* <RichTextToolbarButton
					icon="admin-customizer"
					title={ __( 'Marker', 'keni' ) }
					onClick={ onToggle }
					isActive={ isActive }
				/> */ }
				<BlockControls>
					<Toolbar>
						<ToolbarButton
							className="components-toolbar__control keni-marker keni-marker-blue"
							label="マーカーブルー"
							title="マーカーブルー"
							icon="editor-textcolor"
							onClick={ onToggle }
						/>
					</Toolbar>
				</BlockControls>
			</Fragment>
		);
	},
} );

const markerLime = 'keni-block/marker-lime';
registerFormatType( markerLime, {
	title: __( 'Marker', 'keni' ),
	tagName: 'span',
	className: 'line-lime',
	edit: ( props ) => {
		const {
			value,
			// isActive,
			onChange,
		} = props;

		const onToggle = () => onChange(
			toggleFormat( value, { type: markerLime } )
		);
		const shortcutType = 'ctrlShift';
		return (
			<Fragment>
				<RichTextShortcut
					type={ shortcutType }
					character={ 'l' }
					onUse={ onToggle }
				/>
				{ /* <RichTextToolbarButton
					icon="admin-customizer"
					title={ __( 'Marker', 'keni' ) }
					onClick={ onToggle }
					isActive={ isActive }
				/> */ }
				<BlockControls>
					<Toolbar>
						<ToolbarButton
							className="components-toolbar__control keni-marker keni-marker-lime"
							label="マーカーライム"
							title="マーカーライム"
							icon="editor-textcolor"
							onClick={ onToggle }
						/>
					</Toolbar>
				</BlockControls>
			</Fragment>
		);
	},
} );

const markerGray = 'keni-block/marker-gray';
registerFormatType( markerGray, {
	title: __( 'Marker', 'keni' ),
	tagName: 'span',
	className: 'line-gray',
	edit( props ) {
		const {
			value,
			// isActive,
			onChange,
		} = props;
		const onToggle = () => onChange(
			toggleFormat( value, { type: markerGray } )
		);
		const shortcutType = 'ctrlShift';
		return (
			<Fragment>
				<RichTextShortcut
					type={ shortcutType }
					character={ 'g' }
					onUse={ onToggle }
				/>
				{ /* <RichTextToolbarButton
					icon="admin-customizer"
					title={ __( 'Marker', 'keni' ) }
					onClick={ onToggle }
					isActive={ isActive }
				/> */ }
				<BlockControls>
					<Toolbar>
						<ToolbarButton
							className="components-toolbar__control keni-marker keni-marker-gray"
							label="マーカーグレー"
							title="マーカーグレー"
							icon="editor-textcolor"
							onClick={ onToggle }
						/>
					</Toolbar>
				</BlockControls>
			</Fragment>
		);
	},
} );
